%plot F/Fmsy kernel densities for fisheries starting above and below Fmsy,
%for two ranges of gamma*ln(MSY)


histEdges=[-6.5:1:4.5]; % edges for the region-breakdown histograms
cutoff1=13;
cutoff2=50; %22

%solution line appearances:
SolEdgeWidth=10;
SolEdgeAlpha=0.05;

%start by identifying unique cost/benefit regions
for i=1:length(Fishery_Yr2_EW) %fix fishery subregion (column #3)
    if isempty(Fishery_Yr2_EW{i,3})
        Fishery_Yr2_EW(i,3)={'none'};
    end
end
[Uorder,Uindex,Uall]=unique(round(L,4));
RegionTable=[Uorder NaN(length(Uorder),1)];
RegionTable=[RegionTable(1:3,:);[RegionTable(4,1).*[1 1 1]' [1 2 3]']; RegionTable(5:end,:)];
RegionNamesOrig=Fishery_Yr2_EW(Uindex,2);
USSubRegions={'East';'South';'West'}; %these subregions are for Uindex=4 (United States), coded as 1,2,3 in the RegionTable
USNames={strjoin([RegionNamesOrig{4} USSubRegions{1}]); strjoin([RegionNamesOrig{4} USSubRegions{2}]); strjoin([RegionNamesOrig{4} USSubRegions{3}])};
RegionNames=string([RegionNamesOrig(1:3); USNames; RegionNamesOrig(5:end)]);
RegionNameSearch=string([RegionNamesOrig(1:3); RegionNamesOrig(4); RegionNamesOrig(4); RegionNamesOrig(4); RegionNamesOrig(5:end)]);
RegionNumbers=num2cell([1:1:length(RegionTable) 1:1:length(RegionTable)]);
RegionAbvs=cellstr([RegionAbv;strcat(RegionAbv,'^+')]);

fig=figure ('Color', [1 1 1],'Position',[1 scrsz(2) scrsz(3)/1.5 scrsz(4)]);
set(fig,'defaultAxesColorOrder',[[0 0 0];[0 0 0]]);
%colormap([colorcube(length(RegionTable)); colorcube(length(RegionTable))])
% tempColor=colorcube(length(RegionTable)+20);
%tempColor2=tempColor(1:length(RegionTable),:);
tempColor=jet(length(RegionTable)+10);
tempColor2=tempColor(8:end-3,:);
colormap([tempColor2; tempColor2])

numBoots=10000;
Frange=linspace(-6.5,4.5,100);
subplot(2,2,1)
yyaxis left
%plot data and kernel density curves for gamma*ln(MSY)<13
indicesBelowMSY=find(L.*log(allMSY*1000)<cutoff1  & reshape(firstPt,1,1,[])<0);
indicesAboveMSY=find(L.*log(allMSY*1000)<cutoff1  & reshape(firstPt,1,1,[])>=0);

%obtain and plot theoretical predictions to fisheries with Finit<Fmsy
LlnMSYrange=L(indicesBelowMSY).*log(allMSY(indicesBelowMSY)*1000);
firstPtrange=firstPt(indicesBelowMSY);
belowSolDistr=[];
for i=1:length(LlnMSYrange)
    LMSYlevel=LlnMSYrange(i);
    Fsol=[0; log(1+(1-1/((1/theta)*LMSYlevel))^0.5)/log(2); log(1-(1-1/((1/theta)*LMSYlevel))^0.5)/log(2)];
    Fsol(imag(Fsol)~=0)=-100;
    Fsol=sort(Fsol,'descend');
    Fsol(Fsol==-100)=NaN;
    if firstPtrange(i)<Fsol(2) %first known harvest rate of fishery is less than the unstable equilibrium, thus closer to second lower stable equilibrium (and there is one)
        belowSolDistr(i)=Fsol(3);
    else %datapoint is closer to first higher stable equilibrium (or the model only predicts single equilibrium)
        belowSolDistr(i)=Fsol(1);
    end
%    patchline([belowSolDistr(i) belowSolDistr(i)],[0 0.7],'edgecolor','b','linewidth',SolEdgeWidth,'edgealpha',SolEdgeAlpha);
end

%obtain and plot theoretical predictions to fisheries with Finit>Fmsy
LlnMSYrange=L(indicesAboveMSY).*log(allMSY(indicesAboveMSY)*1000);
firstPtrange=firstPt(indicesAboveMSY);
aboveSolDistr=[];
for i=1:length(LlnMSYrange)
    LMSYlevel=LlnMSYrange(i);
    Fsol=[0; log(1+(1-1/((1/theta)*LMSYlevel))^0.5)/log(2); log(1-(1-1/((1/theta)*LMSYlevel))^0.5)/log(2)];
    Fsol(imag(Fsol)~=0)=-100;
    Fsol=sort(Fsol,'descend');
    Fsol(Fsol==-100)=NaN;
    if firstPtrange(i)<Fsol(2) %first known harvest rate of fishery is less than the unstable equilibrium, thus closer to second lower stable equilibrium (and there is one)
        aboveSolDistr(i)=Fsol(3);
    else %datapoint is closer to first higher stable equilibrium (or the model only predicts single equilibrium)
        aboveSolDistr(i)=Fsol(1);
    end
%    patchline([aboveSolDistr(i) aboveSolDistr(i)],[0 0.7],'edgecolor','r','linewidth',SolEdgeWidth,'edgealpha',SolEdgeAlpha);
end
hold on


% histogram(eF(indicesBelowMSY));
% hold on
% histogram(eF(indicesAboveMSY));
% histogram(bootstrp(numBoots,@mean,eF(indicesBelowMSY)));
% hold on
% histogram(bootstrp(numBoots,@mean,eF(indicesAboveMSY)));
kBelow=ksdensity(reshape(eF(indicesBelowMSY),[],1),Frange);
kAbove=ksdensity(reshape(eF(indicesAboveMSY),[],1),Frange);
area(Frange,kBelow,'FaceColor','w');
hold on
area(Frange,kAbove,'FaceColor','w');
area(Frange,kBelow,'FaceColor','b','FaceAlpha',0.25);
area(Frange,kAbove,'FaceColor','r','FaceAlpha',0.25);
%line([0 0], [0 max([kBelow kAbove])],'LineWidth',2,'Color','k')
xlim([-6.5 4.5])
ylim([0,max([kAbove,kBelow])*1.1])
%ksdensity(reshape(eF([indicesBelowMSY;indicesAboveMSY]),[],1));
overlap1=trapz(Frange,min(kAbove,kBelow))
%[hypo,p1]=kstest2(reshape(eF(indicesBelowMSY),[],1),reshape(eF(indicesAboveMSY),[],1));
[hypo,p1,ci1,tstats1]=ttest2(reshape(eF(indicesBelowMSY),[],1),reshape(eF(indicesAboveMSY),[],1),'Vartype','unequal');
[p1w,hypo,wstats1]=ranksum(reshape(eF(indicesBelowMSY),[],1),reshape(eF(indicesAboveMSY),[],1));
diffmean1=mean(eF(indicesBelowMSY))-mean(eF(indicesAboveMSY))
diffmedian1=median(eF(indicesBelowMSY))-median(eF(indicesAboveMSY))
ci1
p1
p1w
%xlabel(['log_2(F/F_{MSY}), p=' num2str(p1,3)])
xlabel('log_2(F/F_{MSY})')
ylabel('probability density')
%title(['\gammaln(MSY[kg])<' num2str(cutoff) ', #pts=' num2str(length(indicesBelowMSY)) ',' num2str(length(indicesAboveMSY))])
title({['ecologically constrained fisheries'];['\gammaln(MSY[kg])<' num2str(cutoff1)]},'FontWeight','normal')

% %construct stacked histograms with bins centered at log2(F/Fmsy) values of [-6:1:3]
yyaxis right
AboveHist=[];
BelowHist=[];
YearRangeAbove1=[];
YearRangeBelow1=[];

SetBelowF=reshape(eF(indicesBelowMSY),[],1);
SetAboveF=reshape(eF(indicesAboveMSY),[],1);
SetBelowYr=cell2mat(Fishery_Yr2(indicesBelowMSY,3:4));
SetAboveYr=cell2mat(Fishery_Yr2(indicesAboveMSY,3:4));
for re=1:length(RegionTable)
    if re>=4 && re<=6 %US subregions
        RegionBelowF=find(strcmp(string(Fishery_Yr2_EW(indicesBelowMSY,2)),RegionNameSearch{re}).*strcmp(string(Fishery_Yr2_EW(indicesBelowMSY,3)),USSubRegions{re-3}));
        RegionAboveF=find(strcmp(string(Fishery_Yr2_EW(indicesAboveMSY,2)),RegionNameSearch{re}).*strcmp(string(Fishery_Yr2_EW(indicesAboveMSY,3)),USSubRegions{re-3}));
    else
        RegionBelowF=find(strcmp(string(Fishery_Yr2_EW(indicesBelowMSY,2)),RegionNameSearch{re}));
        RegionAboveF=find(strcmp(string(Fishery_Yr2_EW(indicesAboveMSY,2)),RegionNameSearch{re}));
    end
    BelowHist(re,:)=histcounts(SetBelowF(RegionBelowF),histEdges);
    AboveHist(re,:)=histcounts(SetAboveF(RegionAboveF),histEdges);
    if ~isempty(SetBelowYr(RegionBelowF))
        YearRangeBelow1(re,:)=[min(SetBelowYr(RegionBelowF,1)) max(SetBelowYr(RegionBelowF,1)) min(SetBelowYr(RegionBelowF,2)) max(SetBelowYr(RegionBelowF,2))];
    end
    if ~isempty(SetAboveYr(RegionAboveF))
        YearRangeAbove1(re,:)=[min(SetAboveYr(RegionAboveF,1)) max(SetAboveYr(RegionAboveF,1)) min(SetAboveYr(RegionAboveF,2)) max(SetAboveYr(RegionAboveF,2))];
    end
end

FullHist=[BelowHist;AboveHist]';
barCenters=histEdges(1:end-1)+(histEdges(2)-histEdges(1))/2;
bar1=bar(barCenters,FullHist,0.7,'stacked');
% for i=1:length(RegionTable)
%     bar1(i).LineWidth=1;
%     bar1(i).EdgeColor='b';
% end
% for i=length(RegionTable)+1:2*length(RegionTable)
%     bar1(i).LineWidth=2;
%     bar1(i).EdgeColor='r';
% end


for labelx = 1:size(FullHist,1)
    for labely = 1:size(FullHist,2)
        if FullHist(labelx,labely)~=0
            textcolor='k';
            if labely>length(RegionTable)
                textcolor='k';
            end
            text(barCenters(labelx), sum(FullHist(labelx,1:labely-1))+FullHist(labelx,labely)/2, RegionAbvs(labely), 'HorizontalAlignment','center','FontSize',8,'Color',textcolor)
        end
    end
end

ylabel 'count'
%ylim([0,max(sum(FullHist))])

numTransDown1=sum(eF(indicesAboveMSY)<0); %number of initially overharvesting fisheries that became conserving
numTransUp1=sum(eF(indicesBelowMSY)>=0); %number of initially conserving fisheries that became overharvesting
totTransRate1=(numTransDown1+numTransUp1)/(length(indicesAboveMSY)+length(indicesBelowMSY))
TransDownRate1=numTransDown1/length(indicesAboveMSY)
TransUpRate1=numTransUp1/length(indicesBelowMSY)

subplot(2,2,2)
yyaxis left
%plot data and kernel density curves for gamma*ln(MSY)>12 && <22
indicesBelowMSY=find(L.*log(allMSY*1000)>=cutoff1 & L.*log(allMSY*1000)<cutoff2  & reshape(firstPt,1,1,[])<0);
indicesAboveMSY=find(L.*log(allMSY*1000)>=cutoff1 & L.*log(allMSY*1000)<cutoff2  & reshape(firstPt,1,1,[])>=0);
%obtain and plot theoretical predictions to fisheries with Finit<Fmsy
LlnMSYrange=L(indicesBelowMSY).*log(allMSY(indicesBelowMSY)*1000);
firstPtrange=firstPt(indicesBelowMSY);
belowSolDistr=[];
for i=1:length(LlnMSYrange)
    LMSYlevel=LlnMSYrange(i);
    Fsol=[0; log(1+(1-1/((1/theta)*LMSYlevel))^0.5)/log(2); log(1-(1-1/((1/theta)*LMSYlevel))^0.5)/log(2)];
    Fsol(imag(Fsol)~=0)=-100;
    Fsol=sort(Fsol,'descend');
    Fsol(Fsol==-100)=NaN;
    if firstPtrange(i)<Fsol(2) %first known harvest rate of fishery is less than the unstable equilibrium, thus closer to second lower stable equilibrium (and there is one)
        belowSolDistr(i)=Fsol(3);
    else %datapoint is closer to first higher stable equilibrium (or the model only predicts single equilibrium)
        belowSolDistr(i)=Fsol(1);
    end
%    patchline([belowSolDistr(i) belowSolDistr(i)],[0 0.7],'edgecolor','b','linewidth',SolEdgeWidth,'edgealpha',SolEdgeAlpha);
end

%obtain and plot theoretical predictions to fisheries with Finit>Fmsy
LlnMSYrange=L(indicesAboveMSY).*log(allMSY(indicesAboveMSY)*1000);
firstPtrange=firstPt(indicesAboveMSY);
aboveSolDistr=[];
for i=1:length(LlnMSYrange)
    LMSYlevel=LlnMSYrange(i);
    Fsol=[0; log(1+(1-1/((1/theta)*LMSYlevel))^0.5)/log(2); log(1-(1-1/((1/theta)*LMSYlevel))^0.5)/log(2)];
    Fsol(imag(Fsol)~=0)=-100;
    Fsol=sort(Fsol,'descend');
    Fsol(Fsol==-100)=NaN;
    if firstPtrange(i)<Fsol(2) %first known harvest rate of fishery is less than the unstable equilibrium, thus closer to second lower stable equilibrium (and there is one)
        aboveSolDistr(i)=Fsol(3);
    else %datapoint is closer to first higher stable equilibrium (or the model only predicts single equilibrium)
        aboveSolDistr(i)=Fsol(1);
    end
%    patchline([aboveSolDistr(i) aboveSolDistr(i)],[0 0.7],'edgecolor','r','linewidth',SolEdgeWidth,'edgealpha',SolEdgeAlpha);
end
hold on

% histogram(eF(indicesBelowMSY));
% hold on
% histogram(eF(indicesAboveMSY));
% histogram(bootstrp(numBoots,@mean,eF(indicesBelowMSY)));
% hold on
% histogram(bootstrp(numBoots,@mean,eF(indicesAboveMSY)));
kBelow=ksdensity(reshape(eF(indicesBelowMSY),[],1),Frange);
kAbove=ksdensity(reshape(eF(indicesAboveMSY),[],1),Frange);
area(Frange,kBelow,'FaceColor','w');
hold on
area(Frange,kAbove,'FaceColor','w');
area(Frange,kBelow,'FaceColor','b','FaceAlpha',0.25);
area(Frange,kAbove,'FaceColor','r','FaceAlpha',0.25);
%line([0 0], [0 max([kBelow kAbove])],'LineWidth',2,'Color','k')
xlim([-6.5 4.5])
ylim([0,max([kAbove,kBelow])*1.1])
%ksdensity(reshape(eF([indicesBelowMSY;indicesAboveMSY]),[],1));
overlap2=trapz(Frange,min(kAbove,kBelow))
%[hypo,p1]=kstest2(reshape(eF(indicesBelowMSY),[],1),reshape(eF(indicesAboveMSY),[],1));
[hypo,p2,ci2,tstats2]=ttest2(reshape(eF(indicesBelowMSY),[],1),reshape(eF(indicesAboveMSY),[],1),'Vartype','unequal');
[p2w,hypo,wstats2]=ranksum(reshape(eF(indicesBelowMSY),[],1),reshape(eF(indicesAboveMSY),[],1));
diffmean2=mean(eF(indicesBelowMSY))-mean(eF(indicesAboveMSY))
diffmedian2=median(eF(indicesBelowMSY))-median(eF(indicesAboveMSY))
ci2
p2
p2w
%xlabel(['log_2(F/F_{MSY}), p=' num2str(p1,3)])
xlabel('log_2(F/F_{MSY})')
ylabel('probability density')
%title(['\gammaln(MSY[kg])<' num2str(cutoff) ', #pts=' num2str(length(indicesBelowMSY)) ',' num2str(length(indicesAboveMSY))])
title({['intermediate fisheries'];[num2str(cutoff1) '\leq\gammaln(MSY[kg])<' num2str(cutoff2)]},'FontWeight','normal')

%construct stacked histograms with bins centered at log2(F/Fmsy) values of [-6:1:3]
yyaxis right
AboveHist=[];
BelowHist=[];
YearRangeAbove2=[];
YearRangeBelow2=[];

SetBelowF=reshape(eF(indicesBelowMSY),[],1);
SetAboveF=reshape(eF(indicesAboveMSY),[],1);
SetBelowYr=cell2mat(Fishery_Yr2(indicesBelowMSY,3:4));
SetAboveYr=cell2mat(Fishery_Yr2(indicesAboveMSY,3:4));
for re=1:length(RegionTable)
    if re>=4 && re<=6 %US subregions
        RegionBelowF=find(strcmp(string(Fishery_Yr2_EW(indicesBelowMSY,2)),RegionNameSearch{re}).*strcmp(string(Fishery_Yr2_EW(indicesBelowMSY,3)),USSubRegions{re-3}));
        RegionAboveF=find(strcmp(string(Fishery_Yr2_EW(indicesAboveMSY,2)),RegionNameSearch{re}).*strcmp(string(Fishery_Yr2_EW(indicesAboveMSY,3)),USSubRegions{re-3})); 
    else
        RegionBelowF=find(strcmp(string(Fishery_Yr2_EW(indicesBelowMSY,2)),RegionNameSearch{re}));
        RegionAboveF=find(strcmp(string(Fishery_Yr2_EW(indicesAboveMSY,2)),RegionNameSearch{re}));
    end
    BelowHist(re,:)=histcounts(SetBelowF(RegionBelowF),histEdges);
    AboveHist(re,:)=histcounts(SetAboveF(RegionAboveF),histEdges);
    if ~isempty(SetBelowYr(RegionBelowF))
        YearRangeBelow2(re,:)=[min(SetBelowYr(RegionBelowF,1)) max(SetBelowYr(RegionBelowF,1)) min(SetBelowYr(RegionBelowF,2)) max(SetBelowYr(RegionBelowF,2))];
    end
    if ~isempty(SetAboveYr(RegionAboveF))
        YearRangeAbove2(re,:)=[min(SetAboveYr(RegionAboveF,1)) max(SetAboveYr(RegionAboveF,1)) min(SetAboveYr(RegionAboveF,2)) max(SetAboveYr(RegionAboveF,2))];
    end
end

FullHist=[BelowHist;AboveHist]';
barCenters=histEdges(1:end-1)+(histEdges(2)-histEdges(1))/2;
bar2=bar(barCenters,FullHist,0.7,'stacked');
% for i=1:length(RegionTable)
%     bar1(i).LineWidth=1;
%     bar1(i).EdgeColor='b';
% end
% for i=length(RegionTable)+1:2*length(RegionTable)
%     bar1(i).LineWidth=2;
%     bar1(i).EdgeColor='r';
% end


for labelx = 1:size(FullHist,1)
    for labely = 1:size(FullHist,2)
        if FullHist(labelx,labely)~=0
            textcolor='k';
            if labely>length(RegionTable)
                textcolor='k';
            end
            text(barCenters(labelx), sum(FullHist(labelx,1:labely-1))+FullHist(labelx,labely)/2, RegionAbvs(labely), 'HorizontalAlignment','center','FontSize',8,'Color',textcolor)
        end
    end
end

ylabel 'count'
%ylim([0,max(sum(FullHist))])
numTransDown2=sum(eF(indicesAboveMSY)<0); %number of initially overharvesting fisheries that became conserving
numTransUp2=sum(eF(indicesBelowMSY)>=0); %number of initially conserving fisheries that became overharvesting
totTransRate2=(numTransDown2+numTransUp2)/(length(indicesAboveMSY)+length(indicesBelowMSY))
TransDownRate2=numTransDown2/length(indicesAboveMSY)
TransUpRate2=numTransUp2/length(indicesBelowMSY)


subplot(2,2,3)
yyaxis left
%indicesBelowMSY=find(L.*log(allMSY*1000)>=cutoff1  & reshape(firstPt,1,1,[])<0);
%indicesAboveMSY=find(L.*log(allMSY*1000)>=cutoff1  & reshape(firstPt,1,1,[])>=0);
indicesBelowMSY=find(L.*log(allMSY*1000)>=cutoff2  & reshape(firstPt,1,1,[])<0);
indicesAboveMSY=find(L.*log(allMSY*1000)>=cutoff2  & reshape(firstPt,1,1,[])>=0);
%obtain and plot theoretical predictions to fisheries with Finit<Fmsy
LlnMSYrange=L(indicesBelowMSY).*log(allMSY(indicesBelowMSY)*1000);
firstPtrange=firstPt(indicesBelowMSY);
belowSolDistr=[];
for i=1:length(LlnMSYrange)
    LMSYlevel=LlnMSYrange(i);
    Fsol=[0; log(1+(1-1/((1/theta)*LMSYlevel))^0.5)/log(2); log(1-(1-1/((1/theta)*LMSYlevel))^0.5)/log(2)];
    Fsol(imag(Fsol)~=0)=-100;
    Fsol=sort(Fsol,'descend');
    Fsol(Fsol==-100)=NaN;
    if firstPtrange(i)<Fsol(2) %first known harvest rate of fishery is less than the unstable equilibrium, thus closer to second lower stable equilibrium (and there is one)
        belowSolDistr(i)=Fsol(3);
    else %datapoint is closer to first higher stable equilibrium (or the model only predicts single equilibrium)
        belowSolDistr(i)=Fsol(1);
    end
%    patchline([belowSolDistr(i) belowSolDistr(i)],[0 0.7],'edgecolor','b','linewidth',SolEdgeWidth,'edgealpha',SolEdgeAlpha);
end

%obtain and plot theoretical predictions to fisheries with Finit>Fmsy
LlnMSYrange=L(indicesAboveMSY).*log(allMSY(indicesAboveMSY)*1000);
firstPtrange=firstPt(indicesAboveMSY);
aboveSolDistr=[];
for i=1:length(LlnMSYrange)
    LMSYlevel=LlnMSYrange(i);
    Fsol=[0; log(1+(1-1/((1/theta)*LMSYlevel))^0.5)/log(2); log(1-(1-1/((1/theta)*LMSYlevel))^0.5)/log(2)];
    Fsol(imag(Fsol)~=0)=-100;
    Fsol=sort(Fsol,'descend');
    Fsol(Fsol==-100)=NaN;
    if firstPtrange(i)<Fsol(2) %first known harvest rate of fishery is less than the unstable equilibrium, thus closer to second lower stable equilibrium (and there is one)
        aboveSolDistr(i)=Fsol(3);
    else %datapoint is closer to first higher stable equilibrium (or the model only predicts single equilibrium)
        aboveSolDistr(i)=Fsol(1);
    end
%    patchline([aboveSolDistr(i) aboveSolDistr(i)],[0 0.7],'edgecolor','r','linewidth',SolEdgeWidth,'edgealpha',SolEdgeAlpha);
end
hold on

% histogram(eF(indicesBelowMSY));
% hold on
% histogram(eF(indicesAboveMSY));
% histogram(bootstrp(numBoots,@mean,eF(indicesBelowMSY)));
% hold on
% histogram(bootstrp(numBoots,@mean,eF(indicesAboveMSY)));
kBelow=ksdensity(reshape(eF(indicesBelowMSY),[],1),Frange);
kAbove=ksdensity(reshape(eF(indicesAboveMSY),[],1),Frange);
area(Frange,kBelow,'FaceColor','w');
hold on
area(Frange,kAbove,'FaceColor','w');
area(Frange,kBelow,'FaceColor','b','FaceAlpha',0.25);
area(Frange,kAbove,'FaceColor','r','FaceAlpha',0.25);
%line([0 0], [0 max([kBelow kAbove])],'LineWidth',2,'Color','k')
xlim([-6.5 4.5])
ylim([0,max([kAbove,kBelow])*1.1])
%ksdensity(reshape(eF([indicesBelowMSY;indicesAboveMSY]),[],1));
overlap3=trapz(Frange,min(kAbove,kBelow))
[hypo,p3,ci3,tstats3]=ttest2(reshape(eF(indicesBelowMSY),[],1),reshape(eF(indicesAboveMSY),[],1),'Vartype','unequal');
[p3w,hypo,wstats3]=ranksum(reshape(eF(indicesBelowMSY),[],1),reshape(eF(indicesAboveMSY),[],1));
diffmean3=mean(eF(indicesBelowMSY))-mean(eF(indicesAboveMSY))
diffmedian3=median(eF(indicesBelowMSY))-median(eF(indicesAboveMSY))
ci3
p3
p3w


numTransDown3=sum(eF(indicesAboveMSY)<0); %number of initially overharvesting fisheries that became conserving
numTransUp3=sum(eF(indicesBelowMSY)>=0); %number of initially conserving fisheries that became overharvesting
totTransRate3=(numTransDown3+numTransUp3)/(length(indicesAboveMSY)+length(indicesBelowMSY))
TransDownRate3=numTransDown3/length(indicesAboveMSY)
TransUpRate3=numTransUp3/length(indicesBelowMSY)

xlabel('log_2(F/F_{MSY})')
ylabel('probability density')
title({['economically constrained fisheries'];[num2str(cutoff) '\leq\gammaln(MSY[kg])']},'FontWeight','normal')


yyaxis right
AboveHist=[];
BelowHist=[];
YearRangeAbove3=[];
YearRangeBelow3=[];

SetBelowF=reshape(eF(indicesBelowMSY),[],1);
SetAboveF=reshape(eF(indicesAboveMSY),[],1);
SetBelowYr=cell2mat(Fishery_Yr2(indicesBelowMSY,3:4));
SetAboveYr=cell2mat(Fishery_Yr2(indicesAboveMSY,3:4));
for re=1:length(RegionTable)
    if re>=4 && re<=6 %US subregions
        RegionBelowF=find(strcmp(string(Fishery_Yr2_EW(indicesBelowMSY,2)),RegionNameSearch{re}).*strcmp(string(Fishery_Yr2_EW(indicesBelowMSY,3)),USSubRegions{re-3}));
        RegionAboveF=find(strcmp(string(Fishery_Yr2_EW(indicesAboveMSY,2)),RegionNameSearch{re}).*strcmp(string(Fishery_Yr2_EW(indicesAboveMSY,3)),USSubRegions{re-3})); 
    else
        RegionBelowF=find(strcmp(string(Fishery_Yr2_EW(indicesBelowMSY,2)),RegionNameSearch{re}));
        RegionAboveF=find(strcmp(string(Fishery_Yr2_EW(indicesAboveMSY,2)),RegionNameSearch{re}));
    end
    BelowHist(re,:)=histcounts(SetBelowF(RegionBelowF),histEdges);
    AboveHist(re,:)=histcounts(SetAboveF(RegionAboveF),histEdges);
    if ~isempty(SetBelowYr(RegionBelowF))
        YearRangeBelow3(re,:)=[min(SetBelowYr(RegionBelowF,1)) max(SetBelowYr(RegionBelowF,1)) min(SetBelowYr(RegionBelowF,2)) max(SetBelowYr(RegionBelowF,2))];
    end
    if ~isempty(SetAboveYr(RegionAboveF))
        YearRangeAbove3(re,:)=[min(SetAboveYr(RegionAboveF,1)) max(SetAboveYr(RegionAboveF,1)) min(SetAboveYr(RegionAboveF,2)) max(SetAboveYr(RegionAboveF,2))];
    end
end
FullHist=[BelowHist;AboveHist]';
barCenters=histEdges(1:end-1)+(histEdges(2)-histEdges(1))/2;
bar3=bar(barCenters,FullHist,0.7,'stacked');
% for i=length(RegionTable)+1:2*length(RegionTable)
%     bar2(i).LineWidth=2;
%     bar2(i).EdgeColor='r';
% end
RegionNumbers=num2cell([1:1:length(RegionTable) 1:1:length(RegionTable)]);
for labelx = 1:size(FullHist,1)
    for labely = 1:size(FullHist,2)
        if FullHist(labelx,labely)~=0
            textcolor='k';
            if labely>length(RegionTable)
                textcolor='k';
            end
            text(barCenters(labelx), sum(FullHist(labelx,1:labely-1))+FullHist(labelx,labely)/2, RegionAbvs(labely), 'HorizontalAlignment','center','FontSize',8,'Color',textcolor)
        end
    end
end
ylabel 'count'
%ylim([0,max(sum(FullHist))])
colorbar
cbar = colorbar('YTick',[0:0.5/(length(RegionTable)):0.49]+0.0238/2,'YTickLabel',join([strcat(RegionAbv,': '),RegionNames]),'YLim',[0 0.5]);


%
fig=figure ('Color', [1 1 1],'Position',[1 scrsz(2) scrsz(3) scrsz(4)/2.5]);
set(fig,'defaultAxesColorOrder',[[0 0 0];[0 0 0]]);
%plot residuals as function of gamma*ln(MSY)
[LL,LLmeans,Fsols] = RAManalysis_ML_fitF_msy_Yvalues(avgAllPt2,firstPt,ParamEsts); %obtain residuals for all points
%scatter(reshape(log(allMSY*1000).*L,1,[]),LLmeans);

subplot(1,3,1)
indicesBelowMSY=find(L.*log(allMSY*1000)<cutoff1  & reshape(firstPt,1,1,[])<0);
indicesAboveMSY=find(L.*log(allMSY*1000)<cutoff1  & reshape(firstPt,1,1,[])>=0);
histogram(([LLmeans(indicesBelowMSY) LLmeans(indicesAboveMSY)]),10);

subplot(1,3,2)
indicesBelowMSY=find(L.*log(allMSY*1000)>=cutoff1 & L.*log(allMSY*1000)<cutoff2  & reshape(firstPt,1,1,[])<0);
indicesAboveMSY=find(L.*log(allMSY*1000)>=cutoff1 & L.*log(allMSY*1000)<cutoff2  & reshape(firstPt,1,1,[])>=0);
histogram(([LLmeans(indicesBelowMSY) LLmeans(indicesAboveMSY)]),10);

subplot(1,3,3)
indicesBelowMSY=find(L.*log(allMSY*1000)>=cutoff2  & reshape(firstPt,1,1,[])<0);
indicesAboveMSY=find(L.*log(allMSY*1000)>=cutoff2  & reshape(firstPt,1,1,[])>=0);
histogram(([LLmeans(indicesBelowMSY) LLmeans(indicesAboveMSY)]),10);

%ANOVA
%[ANOVAp,ANOVAtbl,ANOVAstats,ANOVAterms]=anovan();