% RAManalysis.m
% Edward Tekwa 8/4/2016
% revised 1/26/2017, 3/8/17

%load RAMdata.mat %data from the RAM legacy database for 1990-2010
%load RAMData_3_all.mat %for 1961-2013 (although >2009 data needs fixing)
%load RAMData_4_all.mat %RAM data for 1961-2013 (although >2009 data needs fixing) + landed values, variable costs, and subsidies (Sumaila et al. 2012)
%load RAMData_5_all.mat %RAM data for 1961-2013 (although >2009 data needs fixing) + landed values, variable costs, subsidies, and per-tonx10^3 values (Sumaila et al. 2012) 3/8/17
%load RAMData_6_all.mat %includes Fishery MSYs in FisheryMSY (col1:name, col2:MSY, col3:MSY from Bmsytouse*Umsytouse)
%load RAMData_7_all.mat %includes Fishery Bmsy in FisheryMSY (col4: Bmsy, col5: Bmsytouse) 12/13/17
load RAMData_8_all.mat %includes B/Bmsy and B/Bmsytouse in FishData (col6,7)  12/14/17
Fish_I=Fish_CostSubsidy_div_Value; %col5:(cost+subsidy)/landed value; col6:value/tonx10^3; col7:(cost+subsidy)/tonx10^3; col8:landings tonx10^3

%plot linear regression of cost vs. landings
CountryCosts=cell2mat(Fish_I(1:142,3))+cell2mat(Fish_I(1:142,4)); %variable cost + subsidy
CountryLandings=cell2mat(Fish_I(1:142,8)); %landings in tonnes x10^3
scrsz = get(0,'ScreenSize');
figure ('Color', [1 1 1],'Position',[1 scrsz(2) scrsz(3)/1.5 scrsz(4)/2.5]);
subplot(1,2,1)
Landings_Costs=fitlm(CountryLandings,CountryCosts)
LCplot=plot(Landings_Costs);
set(LCplot(1),'Marker','o','Color','k','MarkerSize',4)
set(LCplot(2:4),'Color','k','LineWidth',2)
xlabel ({['landings by country [thousand tonnes]'];['p=' num2str(Landings_Costs.Coefficients.pValue(2),3) ', R^2=' num2str(Landings_Costs.Rsquared.Ordinary,3)]},'Interpreter','Tex')
ylabel 'variable cost+subsidy [US$ millions]'
title ''
subplot(1,2,2)
logLandings_Costs=fitlm(log(CountryLandings),log(CountryCosts))
logLCplot=plot(logLandings_Costs);
set(logLCplot(1),'Marker','o','Color','k','MarkerSize',4)
set(logLCplot(2:4),'Color','k','LineWidth',2)
xlabel ({['ln(landings) by country'];['p=' num2str(logLandings_Costs.Coefficients.pValue(2),3) ', R^2=' num2str(logLandings_Costs.Rsquared.Ordinary,3)]},'Interpreter','Tex')
ylabel 'ln(variable cost+subsidy)'
title ''

unimod_p=[];
mode_bounds=[];
multimode_bounds=[];
sig_p=0.05; %p-value for change in harvest rate being zero
%testIWin=[0.05:0.05:round(ImaxReal-IminReal,1)]; %an array of I/V rolling window widths to test
%testFWin=[0.125:.125:3]; %an array of Fwin rolling window widths to test
testIWin=[0.7];
testFWin=[1];
numISteps=50; %analysis x-axis resolution (for all XY maps)
numFSteps=50; %analysis y-axis resolution (for all XY maps)
minPts=1; %minimum number of points to reconstruct harvest rate distribution and harvest rate movement significance
numContours=100; %''; %number of contour lines
numColors=100; %steps for custom colormaps
Cbase=[0:1/numColors:1-1/numColors;0:1/numColors:1-1/numColors;0:1/numColors:1-1/numColors]';

XY=[];
Fishery={};
YrStart=1983; %1961 or 1983
YrEnd=2009;
XYchangeSig=[]; %significance of change
XYchange=[]; %change
for Yr=YrStart:YrEnd
    %XY=[]; %col1: %fish calories, col2: harvest rate relative to msy
    XYmap=[];
    
    for i=1:length(FishData)
        %if FishData{i,4}==Yr && (~isempty(FishData{i,6}) ||
        %~isempty(FishData{i,8})) %(in FishData, column 8 is fitted, 6 is assessed)
        if FishData{i,4}==Yr && ~isempty(FishData{i,5}) %always assessment harvest rate
            %FishID=double(FishData{i,2}(1));
            FishID=sum((10.^[1:length(FishData{i,2})]).*FishData{i,2});
            FisheryMSYID=find(strncmpi(FishData{i,3},FisheryMSY(:,1),50)); %location of MSY data
            if ~isempty(FisheryMSY{FisheryMSYID,2})
                MSY=FisheryMSY{FisheryMSYID,2}; %assessment MSY
            else
                MSY=FisheryMSY{FisheryMSYID,3}; %RAM model MSY
            end
            if ~isempty(FisheryMSY{FisheryMSYID,4}) %assessment r
                rEst=FisheryMSY{FisheryMSYID,4}; %assessment r=2*MSY/Bmsy
            elseif ~isempty(FisheryMSY{FisheryMSYID,5}) %RAM model r
                rEst=FisheryMSY{FisheryMSYID,5}; %RAM model r=2*MSY/Bmsy
            else
                rEst=NaN;
            end
            if rEst==0
                rEst=NaN;
            end
            if ~isempty(FishData{i,6}) %use assessment B/Bmsy if available
                B_Bmsy=FishData{i,6};
            elseif ~isempty(FishData{i,7}) %otherwise use B/Bmsytouse
                B_Bmsy=FishData{i,7};
            end
            XY=[XY;FishData{i,5} 0 0 FishID Yr 0 0 MSY rEst B_Bmsy]; %store relative harvest rate 
            %else %if assessment not available, use model fitted data
            %    XY=[XY;FishData{i,8} 0 0 FishID Yr];
            %end
            Fishery{size(XY,1),1}={FishData{i,3}}; %store fish
            N=3;
            ManageID=find(strncmpi(FishData{i,1},Management(:,1),N));
            while length(ManageID)>1
                N=N+1;
                ManageID=find(strncmpi(FishData{i,1},Management(:,1),N));
            end
            XY(end,3)=ManageID; %store management ID
            Country=Management{ManageID,2};
            commaLoc=find(Country==',');
            commaLoc=[commaLoc length(Country)+1];
            numCountry=sum(Country==',')+1;
            lambda=0;
            avgPrice=0;
            avgCost=0;
            landing=0;
            for j=1:numCountry
                if j==1
                    countryEnd=commaLoc(1)-1;
                    CountryLoc=find(strncmpi(Country(1:countryEnd),Fish_I(:,1),20));
                    %YrLoc=find(cell2mat(Fish_I(CountryLoc,2))==Yr);
                    YrLoc=1;
                    lambda=lambda+Fish_I{CountryLoc(YrLoc),5};
                    avgPrice=avgPrice+Fish_I{CountryLoc(YrLoc),6};
                    avgCost=avgCost+Fish_I{CountryLoc(YrLoc),7};
                    landing=landing+Fish_I{CountryLoc(YrLoc),8};
                else
                    countryEnd=commaLoc(j)-1;
                    CountryLoc=find(strncmpi(Country(commaLoc(j-1)+2:countryEnd),Fish_I(:,1),20));
                    %YrLoc=find(cell2mat(Fish_I(CountryLoc,2))==Yr);
                    YrLoc=1;
                    lambda=lambda+Fish_I{CountryLoc(YrLoc),5};
                    avgPrice=avgPrice+Fish_I{CountryLoc(YrLoc),6};
                    avgCost=avgCost+Fish_I{CountryLoc(YrLoc),7};
                    landing=landing+Fish_I{CountryLoc(YrLoc),8};
                end
            end
            XY(end,2)=lambda/numCountry; %store unweighted average lambda value [mil US$]
            XY(end,6)=avgPrice/numCountry; %store unweighted average landing value/tonx10^3
            XY(end,7)=avgCost/numCountry; %store unweighted average (cost+subsidy)/tonx10^3
%            XY(end,11)=landing; %store total regional landings (10^3 tonnes)
            
            Fishery{size(XY,1),2}={Country}; %store fishery countries
        end
    end
end

XY(find(XY(:,1)<0),1)=NaN; %take out points with negative harvest rate

%reconstruct XY into unique fisheries by year
FisheriesIDs=unique(XY(:,4));
numFisheries=length(FisheriesIDs);
XY_Yr=[];
XY_Yr=nan(YrEnd-YrStart+1,7,numFisheries);
Fishery_Yr={};
for i=1:numFisheries
    for Yr=YrStart:YrEnd
        XYpos=intersect(find(XY(:,4)==FisheriesIDs(i)), find(XY(:,5)==Yr));
        if ~isempty(XYpos)
            XY_Yr(Yr-YrStart+1,:,i)=XY(XYpos,[1:2,6:end]); %columns[1:8]=[harvest rate (F/Fmsy), average cost/benefit, tot benefit, tot cost, MSY, rEst, B/Bmsy, regional total landings]
            Fishery_Yr{i,1}=Fishery{XYpos,1};
            Fishery_Yr{i,2}=Fishery{XYpos,2};
        end
    end
end

%analyze relationship between F/Fmsy (X_t) and B/Bmsy (Y_t+1) for each base
%year
harvestYr=NaN*ones(length(XY_Yr),YrEnd-YrStart);
biomassYr=NaN*ones(length(XY_Yr),YrEnd-YrStart);
for baseYear=1:YrEnd-YrStart+1
    harvestYr(:,baseYear)=reshape(XY_Yr(baseYear,1,:),[],1);
    biomassYr(:,baseYear)=reshape(XY_Yr(baseYear,7,:),[],1);
end

avgAllPt=nanmean(XY_Yr(:,:,:));
avgAllChange=nanmean(diff(XY_Yr(:,:,:)));
varAllF=var(avgPt(1,1,avgPt(1,1,:)<=3));
varAllI=var(avgPt(1,2,:));
