%RAManalysis_timelags.m
%1.) check harvest rate model's performance (R^2) over different time lags
%2.) compare to a null autocorrelation model where t


%load ('RAManalysis fit 100000 F permutations xi model 217pts regional.mat') %this contains both original data for analysis and final analysis outputs for reference
InitLagR2=[];
ModelLagR2=[];
XiLag=[];
LagNumFish=[];

firstAutoPt=[];
avgAllAutoPt2=[];

%calculate stock response to harvest rate within fishery (across years)
KobeCoeffFish=[]; %intercept & slope of linear regression of S/Smsy on F/Fmsy (row 1&2, columns are fisheries)
KobeCoeffSEFish=[]; %intercept & slope standard errors
KobePFish=[]; %intercept & slope p-values
KobeR2Fish=[]; %R^2 of regression
KobePtsFish=[]; %sample pts per year

%calculate autocorrelations
AutoLag=[];
TimeSeriesLength=[];
OneStepAutoCorr=[];
TimeVar=[];
TimeMean=[];

j=1;
for i=1:length(XY_Yr)
    %posFirstPt=min(find(~isnan(XY_Yr(:,1,i)))); %first known time point of current fishery
    posFirstPt=min(find(~isnan(XY_Yr(:,1,i)).*XY_Yr(:,1,i)>0));
    posLastPt=max(find(~isnan(XY_Yr(:,1,i)).*XY_Yr(:,1,i)>0));
    interiorNaN=max(find(isnan(XY_Yr(posFirstPt:posLastPt,1,i)))); %look for last interior NaN and start series after that position
    if ~isnan(interiorNaN)
       posFirstPt=posFirstPt+1+interiorNaN; 
    end
    if log(nanmean(XY_Yr(posFirstPt:end,5,i)))>0
        %[acf,lags,bounds]=autocorr(XY_Yr(posFirstPt:posLastPt,1,i),posLastPt-posFirstPt);
        [acf,lags,bounds]=autocorr(XY_Yr(posFirstPt:posLastPt,1,i),posLastPt-posFirstPt);
        TimeSeriesLength(j)=posLastPt-posFirstPt+1;
        %AutoLag(j)=max(find(acf>=bounds(1) | acf<=bounds(2))); %# find last lag year that is significantly autocorrelated
        AutoLag(j)=min(find(acf<bounds(1) & acf>bounds(2))); %# find first lag year that transitions from significant autocorrelation to insignificant autocorrelation
        firstAutoPt(j,:)=XY_Yr(posFirstPt,1,i);
        avgAllAutoPt2(:,:,j)=nanmean(XY_Yr(posFirstPt+AutoLag(j):posLastPt,:,i));
        OneStepAutoCorr(j)=acf(2);
        TimeVar(j)=nanvar(XY_Yr(posFirstPt:posLastPt,1,i));
        TimeMean(j)=nanmean(XY_Yr(posFirstPt:posLastPt,1,i));
        
        %KobeFit=fitlm(XY_Yr(posFirstPt:posLastPt,1,i),XY_Yr(posFirstPt:posLastPt,7,i)); %x=harvest rate/Fmsy, y=biomass/bmsy
        KobeFit=fitlm(XY_Yr(posFirstPt:posLastPt,7,i),XY_Yr(posFirstPt:posLastPt,1,i)); %x=harvest rate/Fmsy, y=biomass/bmsy
        KobeCoeffFish(:,j)=KobeFit.Coefficients.Estimate; %intercept & slope of linear regression of S/Smsy on F/Fmsy (row 1&2, columns are years)
        KobeCoeffSEFish(:,j)=KobeFit.Coefficients.SE; %intercept & slope standard errors
        KobePFish(:,j)=KobeFit.Coefficients.pValue; %intercept & slope p-values
        KobeR2Fish(j)=KobeFit.Rsquared.Ordinary; %R^2 of regression
        KobePtsFish(j)=KobeFit.NumObservations; %sample pts per year
        j=j+1;
    end
end

%analyze ecological response to harvest rate using logistic growth model (from each fishery's Kobe plots)
meanKobeCoeffsFish=mean(KobeCoeffFish,2)
stdKobeIntFish=std(KobeCoeffFish(1,:))
stdKobeSlopeFish=std(KobeCoeffFish(2,:))
meanKobeR2Fish=mean(KobeR2Fish)
stdKobeR2Fish=std(KobeR2Fish)
meanKobePFish=mean(KobePFish')
stdKobePFish=std(KobePFish')
maxKobePFish=max(KobePFish')
numSigFish=sum(KobePFish(2,:)<0.05) %number of fisheries exhibiting significant ecological response to harvest rate (slope not 0)

%fit model with different time lags for each time series, based on
%autocorrelation analyses
firstAutoPt=log2(firstAutoPt); %use log2(F)
avgAllAutoPt2(:,1,:)=log2(avgAllAutoPt2(:,1,:)); %use log2(F)
autoL=avgAllAutoPt2(:,2,:);
autoF=avgAllAutoPt2(:,1,:);
autoMSY=avgAllAutoPt2(:,5,:);
autoFMean=nanmean(autoF);
autoFTot=nansum((autoFMean-autoF).^2);

STotAutoBelowMean=nansum(reshape((nanmean(autoF(firstAutoPt<0))-autoF(firstAutoPt<0)).^2,1,[])); %total weighted sum of squares
STotAutoAboveMean=nansum(reshape((nanmean(autoF(firstAutoPt>=0))-autoF(firstAutoPt>=0)).^2,1,[])); %total weighted sum of squares
InitAutoR2=1-(STotAutoBelowMean+STotAutoAboveMean)/autoFTot
freeparmin1=[1 1000];
freeparmax1=[30 1000]; %[1000 1000]

numTries=5;
i=1;
while i<=numTries % 10 fit attempts
    freeparstartN=freeparmin1+(freeparmax1-freeparmin1).*rand(1,2); %[E xi R b]=[imperfection term, evol rate, r*Smsy, beta(risk aversion)]
    if i==1
        freeparstartN=freeparstart;
    end
    [ParamEstsN,fvalN,exitflag,output] = fminsearchbnd(@(params) RAManalysis_ML_fitF_msy(avgAllAutoPt2,firstAutoPt,params),freeparstartN,freeparmin,freeparmax,options);
    if i==1
        fval=fvalN;
        ParamEstsBest=ParamEstsN;
    elseif fvalN<fval
        fval=fvalN;
        ParamEstsBest=ParamEstsN;
    end
    disp(['Autocorrelation elimated: R^2=' num2str(1-fvalN/autoFTot) ', LL=' num2str(fvalN) ', \xi=' num2str(ParamEstsN(1)) ', MSY unit [1000kg/#]=' num2str(ParamEstsN(2))]);
    i=i+1;
end

ModelAutoR2=1-fval/autoFTot;
XiAuto=ParamEstsBest(1);
RAMHarvestContour(autoL,autoF,autoMSY,firstAutoPt,XiAuto); %plot data, model, and data contours
 
fig=figure('Color', [1 1 1]);
subplot(2,2,1)
LMSY_FirstUnCor=fitlm(reshape(log(autoMSY*1000).*autoL,1,[]),AutoLag)
%FirstUnCorPlot=plot(LMSY_FirstUnCor);
scatter(reshape(log(autoMSY*1000).*autoL,1,[]),AutoLag,'ok')
hold on
% set(FirstUnCorPlot(1),'Marker','o','Color','k','MarkerSize',4)
% set(FirstUnCorPlot(2:4),'Color','k','LineWidth',2)
xlabel ({'\gammaln(MSY[kg])';['p=' num2str(LMSY_FirstUnCor.Coefficients.pValue(2),3) ', R^2=' num2str(LMSY_FirstUnCor.Rsquared.Ordinary,3)]},'Interpreter','Tex')
ylabel 'first uncorrelated time lag [yr]'
title ''
legend off
xlim([6 45])
% histogram(AutoLag)
% xlabel 'first uncorrelated time lag [yr]'
% ylabel 'frequency'
subplot(2,2,2)
LMSY_Var=fitlm(reshape(log(autoMSY*1000).*autoL,1,[]),log2((TimeVar.^(1/2))./TimeMean))
VarPlot=plot(LMSY_Var);
set(VarPlot(1),'Marker','o','Color','k','MarkerSize',4)
set(VarPlot(2:4),'Color','k','LineWidth',2)
xlabel ({'\gammaln(MSY[kg])';['p=' num2str(LMSY_Var.Coefficients.pValue(2),3) ', R^2=' num2str(LMSY_Var.Rsquared.Ordinary,3)]},'Interpreter','Tex')
ylabel ('log_2(harvest rate time std/mean)','interpreter','tex')
title ''
legend off
xlim([6 45])
subplot(2,2,3)
% scatter(reshape(log(autoMSY*1000).*autoL,1,[]),OneStepAutoCorr)
LMSY_AutoCor=fitlm(reshape(log(autoMSY*1000).*autoL,1,[]),OneStepAutoCorr)
AutoCorPlot=plot(LMSY_AutoCor);
hold on
set(AutoCorPlot(1),'Marker','o','Color','k','MarkerSize',4)
set(AutoCorPlot(2:4),'Color','k','LineWidth',2)
xlabel ({'\gammaln(MSY[kg])';['p=' num2str(LMSY_AutoCor.Coefficients.pValue(2),3) ', R^2=' num2str(LMSY_AutoCor.Rsquared.Ordinary,3)]},'Interpreter','Tex')
ylabel 'harvest rate autocorrelation (1 yr)'
title ''
legend off
xlim([6 45])
subplot(2,2,4)
%scatter(reshape(log(autoMSY*1000).*autoL,1,[]),log(TimeVar))
LMSY_Var=fitlm(reshape(log(autoMSY*1000).*autoL,1,[]),log2(TimeVar))
VarPlot=plot(LMSY_Var);
set(VarPlot(1),'Marker','o','Color','k','MarkerSize',4)
set(VarPlot(2:4),'Color','k','LineWidth',2)
xlabel ({'\gammaln(MSY[kg])';['p=' num2str(LMSY_Var.Coefficients.pValue(2),3) ', R^2=' num2str(LMSY_Var.Rsquared.Ordinary,3)]},'Interpreter','Tex')
ylabel ('log_2(harvest rate time variance)','interpreter','tex')
title ''
legend off
xlim([6 45])

fig=figure('Color', [1 1 1]); %nicer figure for time variance
LMSY_Var=fitlm(reshape(log(autoMSY*1000).*autoL,1,[]),log2(TimeVar));
numVals=100;
xval = 6:(45-6)/(numVals-1):45;
[ynew, ci] = predict(LMSY_Var, xval');
b = [ynew-ci(:,1) ci(:,2)-ynew];
boundedline(xval,ynew',b,'k')
hold on
scatter(reshape(log(autoMSY*1000).*autoL,1,[]),log2(TimeVar),8,'k','filled');
xlabel ({'\gammaln(MSY_{kg})';['p=' num2str(LMSY_Var.Coefficients.pValue(2),3) ', R^2=' num2str(LMSY_Var.Rsquared.Ordinary,3)]},'Interpreter','Tex')
ylabel ('log_2(harvest rate time variance)','interpreter','tex')
title ''
legend off
xlim([6 45])

for LagGap=1:46
    %prepare data for a particular lag beteen first point and point to predict (dependent variable)
    avgAllLagPt2=[];
    firstLagPt=[]; %first point
    lastLagPt2=[]; %last point (dependent variable)
    j=1;
    for i=1:length(XY_Yr)
        posFirstPt=min(find(~isnan(XY_Yr(:,1,i)).*XY_Yr(:,1,i)>0));
        posLastPt=max(find(~isnan(XY_Yr(:,1,i)).*XY_Yr(:,1,i)>0));
        if log(nanmean(XY_Yr(posFirstPt:end,5,i)))>0
            firstLagPt(j,:)=XY_Yr(posFirstPt,1,i);
            avgAllLagPt2(:,:,j)=nanmean(XY_Yr(min(posFirstPt+LagGap,posLastPt):posLastPt,:,i)); %take average removing first TimeGap (5) time points
            j=j+1;
        end
    end
    validPos=avgAllLagPt2(1,1,:)~=0 & log(avgAllLagPt2(1,5,:))>0 & reshape(TimeSeriesLength,1,1,[])>LagGap+2; %find fisheries where harvest rate is not zero, ln(MSY)>0, and time series length>LagGap
    avgAllLagPt2=avgAllLagPt2(1,:,validPos);
    firstLagPt=firstLagPt(validPos,1);
    firstLagPt=log2(firstLagPt); %use log2(F)
    avgAllLagPt2(:,1,:)=log2(avgAllLagPt2(:,1,:)); %use log2(F)
    lagL=avgAllLagPt2(:,2,:);
    lagF=avgAllLagPt2(:,1,:);
    lagMSY=avgAllLagPt2(:,5,:);
    
    
    lagFMean=nanmean(lagF);
    lagFTot=nansum((lagFMean-lagF).^2);
    
    STotLagBelowMean=nansum(reshape((nanmean(lagF(firstLagPt<0))-lagF(firstLagPt<0)).^2,1,[])); %total weighted sum of squares
    STotLagAboveMean=nansum(reshape((nanmean(lagF(firstLagPt>=0))-lagF(firstLagPt>=0)).^2,1,[])); %total weighted sum of squares
    InitLagR2(LagGap)=1-(STotLagBelowMean+STotLagAboveMean)/lagFTot;
    freeparmin1=[1 1000];
    freeparmax1=[100 1000]; %[1000 1000]
    
    numTries=5;
    i=1;
    while i<=numTries % 10 fit attempts
        freeparstartN=freeparmin1+(freeparmax1-freeparmin1).*rand(1,2); %[E xi R b]=[imperfection term, evol rate, r*Smsy, beta(risk aversion)]
        if i==1
            freeparstartN=freeparstart;
        end
        [ParamEstsN,fvalN,exitflag,output] = fminsearchbnd(@(params) RAManalysis_ML_fitF_msy(avgAllLagPt2,firstLagPt,params),freeparstartN,freeparmin,freeparmax,options);
        if i==1
            fval=fvalN;
            ParamEstsBest=ParamEstsN;
        elseif fvalN<fval
            fval=fvalN;
            ParamEstsBest=ParamEstsN;
        end
        disp(['Lag=' num2str(LagGap) ':' num2str(i) ',R^2=' num2str(1-fvalN/lagFTot) ', LL=' num2str(fvalN) ', \xi=' num2str(ParamEstsN(1)) ', MSY unit [1000kg/#]=' num2str(ParamEstsN(2))]);
        i=i+1;
%         if 1-fval/lagFTot<=InitLagR2(LagGap) %if model is worse than initial condition model, keep trying
%             i=numTries;
%         end  
    end
    
    ModelLagR2(LagGap)=1-fval/lagFTot;
    XiLag(LagGap)=ParamEstsBest(1);
    LagNumFish(LagGap)=length(lagF);
    
    %RAMHarvestContour(lagL,lagF,lagMSY,firstLagPt,XiLag(LagGap));
    
end

fig=figure('Color', [1 1 1]);
set(fig,'defaultAxesColorOrder',[[0 0 0];[0 0 1]]);
yyaxis left
plot(ModelLagR2,'k','LineWidth',2)
hold on
plot(InitLagR2,'k--','LineWidth',2)
xlabel 'time lag [yr]'
ylabel 'R^2'
yyaxis right
plot(XiLag,'b','LineWidth',2)
legend({'harvest rate model';'initial condition model';'\xi'})
ylabel '\xi estimate'
hold on
%plot(LagNumFish)