%RAManalysis_transitions.m
%Edward Tekwa Aug 9, 18
%Fit model to only fisheries that have transitioned across Fmsy, with new
%initial condition matching the current state, which is the opposite of the
%original initial year condition.

indicesTransUp=find(reshape(firstPt,1,1,[])<0 & reshape(eF,1,1,[])>=0); %find indices of fisheries that transitioned to overharvesting
indicesTransDown=find(reshape(firstPt,1,1,[])>=0 & reshape(eF,1,1,[])<0); %find indices of fisheries that transitioned to conservation

Alltrans=avgAllPt2(:,:,[indicesTransUp;indicesTransDown]);
Ftrans=Alltrans(:,1,:);
firstPtTrans=-1*firstPt([indicesTransUp;indicesTransDown]); %invert initial conditions so that model explains what happens after transition
meanSS=sum((Ftrans(1,1,:)-mean(Ftrans(1,1,:))).^2); %sum of squares of mean

fvalTrans=Inf;
ParamEstsTrans=ParamEsts;
R2TransModel=-Inf;

disp('fitting model to transitioned fisheries by estimating N:');
for i=1:5
    prevLLdF=STotDir;
    prevLLF=SWeightedmeans;
    freeparstartN=freeparmin+(freeparmax-freeparmin).*rand(1,2); %[E N R b]=[imperfection term, evol rate, r*Smsy, beta(risk aversion)]
    if i==1
        freeparstartN=freeparstart;
    end
    %to fit model to harvest rates, use all data:
    [ParamEstsN,fvalN,exitflag,output] = fminsearchbnd(@(params) RAManalysis_ML_fitF_msy(Alltrans,firstPtTrans,params),freeparstartN,freeparmin,freeparmax,options);
    R2N=1-fvalN/meanSS;
    disp([num2str(i) ',R^2=' num2str(R2N) ', LL=' num2str(fvalN) ', N=' num2str(ParamEstsN(1)) ', MSY unit [1000kg/#]=' num2str(ParamEstsN(2))]);
    if fvalN<fvalTrans
        fvalTrans=fvalN;
        %freeparstart=freeparstartN;
        ParamEstsTrans=ParamEstsN;
        R2TransModel=R2N;
    end
end

%statistical model with two constant lines for the two initial condition groups
STotBelowMeanTrans=nansum(reshape((nanmean(Ftrans(firstPtTrans<0))-Ftrans(firstPtTrans<0)).^2,1,[])); %total weighted sum of squares
STotAboveMeanTrans=nansum(reshape((nanmean(Ftrans(firstPtTrans>=0))-Ftrans(firstPtTrans>=0)).^2,1,[])); %total weighted sum of squares
AboveBelowMeansTransR2=1-(STotBelowMeanTrans+STotAboveMeanTrans)/meanSS


%randomize data, reapply weighting according to original rolling windows,
%and assess new model fit to the randomized data (R^2 distribution)

R2RandDist_vsNull=[];
RDist=[];

display('starting randomization:');
numRand=100000;
for i=1:numRand
    randL=Alltrans(1,2,:); %original I/V data
    randFOrder=randperm(size(Ftrans,3));
    randF=Ftrans(randFOrder); %randomized harvest rates
    randFirstPt=firstPtTrans(randFOrder); %preserve initial condition with fishery
    randMSY=Alltrans(1,5,:); %preserve MSY with I/V

    %fit full model to randomized data
    if fitType==1
        %fit to data with cost/benefit randomized by fisheries
        [ParamEstsBoot,fvalBoot,exitflag,output] = fminsearchbnd(@(params) RAManalysis_ML_fitF_msy([randF randL zeros(1,1,length(randF)) zeros(1,1,length(randF)) randMSY],randFirstPt,params),freeparstart,freeparmin,freeparmax,options);
        %fit to data with cost/benefit randomized by (21) regions
%         [ParamEstsBootReg,fvalBootReg,exitflag,output] = fminsearchbnd(@(params) RAManalysis_ML_fitF_msy([eF reshape(randRegionL,1,1,[]) zeros(1,1,length(randF)) zeros(1,1,length(randF)) randMSY2],firstPt,params),freeparstart,freeparmin,freeparmax,options);
%         for j=0:0 %extra checks: try random inital guesses
%             freeparstartN=freeparmin+(freeparmax-freeparmin).*rand(1,2); %random initial guess
%             [ParamEstsBootN,fvalBootN,exitflag,output] = fminsearchbnd(@(params) RAManalysis_ML_fitF_msy([randF randL zeros(1,1,length(randF)) zeros(1,1,length(randF)) randMSY],randFirstPt,params),freeparstartN,freeparmin,freeparmax,options);
%             if fvalBootN<fvalBoot
%                 fvalBoot=fvalBootN;
%                 ParamEstsBoot=ParamEstsBootN;
%             end
%         end
        randLL=fvalBoot;
    end
    R2RandDist_vsNull(i)=1-randLL/meanSS;
    RDist(i)=ParamEstsBoot(1);
    pTemp=sum(R2RandDist_vsNull>=R2TransModel)/length(R2RandDist_vsNull);
    display([num2str(i) ' F R^2: ' num2str(R2RandDist_vsNull(i)) ', N=' num2str(ParamEstsBoot(1)) ', w=' num2str(ParamEstsBoot(2)) ', p=' num2str(pTemp) ]);
end
pFModel_vsNull=sum(R2RandDist_vsNull>=R2TransModel)/length(R2RandDist_vsNull)
% pN=2*min(sum(ParamEsts(1)>=RDist)/length(RDist),sum(ParamEsts(1)<RDist)/length(RDist)) %2-sided test